==> socratadata_0.1.0.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/2asz-g9qq.json-9aaaf6.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/2asz-g9qq.json?%24select=plain_text_column%2C%20formatted_text_column%20as%20html&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Tue, 22 Jul 2025 20:42:02 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxNF82XzIyOXo3TkRPaG4xVE5UTFdHd2NqMDNJMmlSLW5UOA-ZbpLXlSVjpwWsMv6ncsQe4B-2QQ--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"plain_text_column\",\"html\"]", 
        `X-SODA2-Types` = "[\"text\",\"text\"]", `X-SODA2-Data-Out-Of-Date` = "false", 
        `X-SODA2-Truth-Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", 
        `Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "cc237b24fecdc396d26fc2aa848ff25f"), class = "httr2_headers"), 
    body = charToRaw("[{\"plain_text_column\":\"Sample Text\",\"html\":\"<p>Sample <strong>Rich Text</strong></p>\"}]\n"), 
    timing = c(redirect = 0, namelookup = 1.2e-05, connect = 0, 
    pretransfer = 5.8e-05, starttransfer = 0.207351, total = 0.207447
    ), cache = new.env(parent = emptyenv())), class = "httr2_response")

==> socratadata_0.1.1.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/2asz-g9qq.json-9aaaf6.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/2asz-g9qq.json?%24select=plain_text_column%2C%20formatted_text_column%20as%20html&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Mon, 18 Aug 2025 16:30:59 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxNF82XzIyOXo3TkRPaG4xVE5UTFdHd2NqMDNJMmlSLW5UOA-ZbpLXlSVjpwWsMv6ncsQe4B-2QQ--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"plain_text_column\",\"html\"]", 
        `X-SODA2-Types` = "[\"text\",\"text\"]", `X-SODA2-Data-Out-Of-Date` = "false", 
        `X-SODA2-Truth-Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", 
        `Last-Modified` = "Mon, 16 Sep 2019 23:13:03 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "47aeefb23ba09cc1d97263aa77ccb81d"), class = "httr2_headers"), 
    body = charToRaw("[{\"plain_text_column\":\"Sample Text\",\"html\":\"<p>Sample <strong>Rich Text</strong></p>\"}]\n"), 
    timing = c(redirect = 0, namelookup = 0.059707, connect = 0.081429, 
    pretransfer = 0.130701, starttransfer = 0.343284, total = 0.343396
    ), cache = new.env(parent = emptyenv())), class = "httr2_response")
